@@ -4,38 +4,31 @@
  ***
  ***/
  
-#ifndef TRUE
-#define TRUE (1)
-#endif
-#ifndef FALSE
-#define FALSE (-1)
-#endif
- 
-
-/*  gives compiler error ... 
 #ifndef _COMPAT_H
 #define _COMPAT_H
-*/
- 
+
 #define NeedFunctionPrototypes 1
 
 #include <stdio.h>
+#include <unistd.h>
+
 #define ErrorF printf
 
-
-void GlennsIODelay();
-
 typedef void *ScrnInfoRec;  /* dummy, not used by SVGATextMode */
 
+extern void GlennsIODelay();
+
+extern int CirrusSetClock(int freq);
 
 int xf86DisableInterrupts();
 
 void xf86EnableInterrupts();
 
 void s3OutTiIndReg(unsigned char reg, unsigned char mask, unsigned char data);
+unsigned char s3InTiIndReg(unsigned char reg);
+
+void xfree_Ti3025_init(int optmask);
 
 
-/*
 #endif
-*/
 
